# `frontmatter-to-csv` - Convert YAML front matter to CSV

This simple Python script will convert fields from the YAML front matter to your specified CSV fields.
Optionally, it can transform some of the fields:

* convert Python lists to comma-joined lists
* convert varied human-readable durations to unified unit (hours)